==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/de/pub.php <==
<?php
regGS("trial subscription", "Probe Abonnement");
regGS("paid subscription", "Bezahltes Abonnement");
regGS("time units", "Zeiteinheiten");
regGS("one language", "Eine Sprache");
regGS("all languages", "Alle Sprachen");
regGS("Trial subscriptions", "Probe Abonnements");
regGS("Time unit cost per one section", "Kosten der Zeiteinheit für eine Rubrik");
regGS("Paid subscriptions", "Bezahlte Abonnements");
regGS("Default time period", "Voreinstellung der Zeiteinheit");
regGS("Publication List", "Liste der Publikationen");
regGS("Go To Issues", "Gehe zu Ausgabe");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", "Name");
regGS("Delete publication $1", "Publikation $1 löschen");
regGS("No publications.", "Keine Publikationen");
regGS("Default Site Alias", "Alias der voreingestellten Seite");
regGS("URL Type", "URL Typ");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "Land (bearbeiten, bitte anklicken)");
regGS("Delete alias $1", "Eintrag $1 löschen");
regGS("Configure publication", "Publikation konfigurieren");
regGS("You do not have the right to edit publication information.", "Keine Berechtigung Info der Publikation zu ändern");
regGS("General attributes", "Allgemeine Eigenschaften");
regGS("Subscriptions defaults", "Abonnement Voreinstellungen");
regGS("Countries defaults", "Länder Voreinstellungen");
regGS("Changing publication information", "Info der Publikation wird geändert");
regGS("You do not have the right to change publication information.", "Keine Rechte Info der Publikation zu ändern");
regGS("The publication information could not be updated.", "Die Info der Publikations konnte nicht verändert werden");
regGS("Please check if another publication with the same name or the same site name does not already exist.", "Bitte überprüfen, ob eine Publikation mit dem selben Namen schon existiert");
regGS("You do not have the right to delete publications.", "Keine Berechtigung Publikationen zu löschen");
regGS("Are you sure you want to delete the publication $1?", "Sicher, dass Publikation $1 gelöscht werden soll?");
regGS("Deleting publication", "Publikation wird gelöscht");
regGS("There are $1 subscription(s) left.", "$1 Abonement(s) noch vorhanden");
regGS("The publication $1 could not be deleted.", "Publikation $1 konnte nicht gelöscht werden");
regGS("Adding new publication", "Neue Publikatin hinzufügen");
regGS("The publication could not be added.", "Publikation konnte nicht hinzugefügt werden");
regGS("Add new country default subscription time", "Neue Länderstandardzeit für Abonoments hinzufügen");
regGS("You do not have the right to manage publications.", "Keine Berechtigung, die Publikation zu verändern");
regGS("Please check if another entry with the same country code exists already.", "Bitte prüfen, ob ein Eintrag mit diesem Ländercode schon existiert.");
regGS("Adding new country default subscription time", "Hinzufügen von für Abonomentstandardzeit ");
regGS("You must select a country.", "Es muss ein Land gewählt werden");
regGS("The default subscription time for country $1 could not be added.", "Abonomentstandardzeit für das Land $1 konnte nicht hinzugefügt werden");
regGS("Change subscription default time", "Abonomentstandardzeit  ändern");
regGS("Default subscription time for $1 changed", "Abonomentstandardzeit  für $1 hat sich geändert");
regGS("Are you sure you want to delete the subscription default time for $1?", "Sicher, die Abonomentstandardzeit  für $1 zu löschen?");
regGS("Subscription default time for $1 deleted", "Abonomentstandardzeit  für $1 gelöscht");
regGS("Add new alias", "Neuen Alias hinzufügen");
regGS("Alias (click to edit)", "Alias (anklicken zum editieren)");
regGS("Edit aliases", "Aliase editieren");
regGS("Publication Aliases", "Aliase der Publikationen");
regGS("Adding new alias", "Neuen Alias hinzufügen");
regGS("The site alias $1 has been added to publication $2.", "Der Alias $1 der Seite wurde zu Publikation $2 hinzugefügt");
regGS("The site alias $1 could not be added.", "Alias $1 für die Seite konnte nicht hinzugefügt werden.");
regGS("Another alias with the same name exists already.", "Ein anderer Alias mit dem gleichen Namen existiert bereits.");
regGS("Edit alias", "Alias editieren");
regGS("Editing alias", "Alias editieren");
regGS("The site alias for publication $1 has been modified to $2.", "Alias der Publikation $1 wurde zu $2 geändert.");
regGS("The site alias $1 could not be modified.", "Der Alias $1 der Seite konnte nicht modifiziert werden.");
regGS("Are you sure you want to delete the alias $1?", "Soll Alias $1 wirklich gelöscht werden?");
regGS("Deleting alias", "Alias löschen");
regGS("The alias $1 could not be deleted.", "Alias $1 konnte nicht gelöscht werden.");
regGS("The alias $1 has been deleted from publication $2.", "Alias $1 wurde von Publikation $2 entfernt.");
regGS("$1 is the default publication alias, it can not be deleted.", "$1 ist der voreingestellte Alias der Publikation und kann nicht gelöscht werden.");
regGS("You do not have the right to add publications.", "Keine Zugriffsrechte eine neue Publikation zu erstellen.");
regGS("There are $1 issue(s) left.", "$1 Ausgaben sind übrig.");
regGS("Change publication information", "Information der Publikation ändern");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/de/pub.php <==
<?php 
regGS("Use CAPTCHA to prevent spam?", "");
regGS("Public allowed to comment?", "");
regGS("Enable spam blocking?", "");
regGS("The subscription settings for '$1' could not be added.", "");
regGS("The publication name you specified conflicts with publication '$1'.", "");
regGS("The publication alias you specified conflicts with publication '$1'.", "");
regGS("Subscription defaults", "");
regGS("Subscription Settings by Country", "");
regGS("Set subscription settings for a country", "");
regGS("Set subscription settings by country", "");
regGS("Default time periods:", "");
regGS("Country subscription settings updated.", "");
regGS("Country subscription settings deleted.", "");
regGS("Change country subscription settings", "");
regGS("Are you sure you want to delete the subscription settings for $1?", "");
regGS("Publication updated", "");
regGS("Subscriber comments moderated?", "");
regGS("Public comments moderated?", "");
regGS("Comments enabled?", "");
regGS("Comments enabled", "");
regGS("Article comments default to enabled?", "");
regGS("trial subscription", "Probe Abonnement");
regGS("paid subscription", "Bezahltes Abonnement");
regGS("time units", "Zeiteinheiten");
regGS("one language", "Eine Sprache");
regGS("all languages", "Alle Sprachen");
regGS("Trial subscriptions", "Probe Abonnements");
regGS("Time unit cost per one section", "Kosten der Zeiteinheit für eine Rubrik");
regGS("Paid subscriptions", "Bezahlte Abonnements");
regGS("Default time period", "Voreinstellung der Zeiteinheit");
regGS("Go To Issues", "Gehe zu Ausgabe");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", "Name");
regGS("Delete publication $1", "Publikation $1 löschen");
regGS("No publications.", "Keine Publikationen");
regGS("Default Site Alias", "Alias der voreingestellten Seite");
regGS("URL Type", "URL Typ");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "Land (bearbeiten, bitte anklicken)");
regGS("Delete alias $1", "Eintrag $1 löschen");
regGS("Configure publication", "Publikation konfigurieren");
regGS("You do not have the right to edit publication information.", "Keine Berechtigung Info der Publikation zu ändern");
regGS("General attributes", "Allgemeine Eigenschaften");
regGS("You do not have the right to change publication information.", "Keine Rechte Info der Publikation zu ändern");
regGS("The publication information could not be updated.", "Die Info der Publikations konnte nicht verändert werden");
regGS("You do not have the right to delete publications.", "Keine Berechtigung Publikationen zu löschen");
regGS("Are you sure you want to delete the publication $1?", "Sicher, dass Publikation $1 gelöscht werden soll?");
regGS("Deleting publication", "Publikation wird gelöscht");
regGS("There are $1 subscription(s) left.", "$1 Abonement(s) noch vorhanden");
regGS("The publication $1 could not be deleted.", "Publikation $1 konnte nicht gelöscht werden");
regGS("The publication could not be added.", "Publikation konnte nicht hinzugefügt werden");
regGS("You do not have the right to manage publications.", "Keine Berechtigung, die Publikation zu verändern");
regGS("You must select a country.", "Es muss ein Land gewählt werden");
regGS("Default subscription time for $1 changed", "Abonomentstandardzeit  für $1 hat sich geändert");
regGS("Subscription default time for $1 deleted", "Abonomentstandardzeit  für $1 gelöscht");
regGS("Add new alias", "Neuen Alias hinzufügen");
regGS("Alias (click to edit)", "Alias (anklicken zum editieren)");
regGS("Edit aliases", "Aliase editieren");
regGS("Publication Aliases", "Aliase der Publikationen");
regGS("Adding new alias", "Neuen Alias hinzufügen");
regGS("The site alias $1 has been added to publication $2.", "Der Alias $1 der Seite wurde zu Publikation $2 hinzugefügt");
regGS("The site alias $1 could not be added.", "Alias $1 für die Seite konnte nicht hinzugefügt werden.");
regGS("Another alias with the same name exists already.", "Ein anderer Alias mit dem gleichen Namen existiert bereits.");
regGS("Edit alias", "Alias editieren");
regGS("Editing alias", "Alias editieren");
regGS("The site alias for publication $1 has been modified to $2.", "Alias der Publikation $1 wurde zu $2 geändert.");
regGS("The site alias $1 could not be modified.", "Der Alias $1 der Seite konnte nicht modifiziert werden.");
regGS("Are you sure you want to delete the alias $1?", "Soll Alias $1 wirklich gelöscht werden?");
regGS("Deleting alias", "Alias löschen");
regGS("The alias $1 could not be deleted.", "Alias $1 konnte nicht gelöscht werden.");
regGS("The alias $1 has been deleted from publication $2.", "Alias $1 wurde von Publikation $2 entfernt.");
regGS("$1 is the default publication alias, it can not be deleted.", "$1 ist der voreingestellte Alias der Publikation und kann nicht gelöscht werden.");
regGS("You do not have the right to add publications.", "Keine Zugriffsrechte eine neue Publikation zu erstellen.");
regGS("There are $1 issue(s) left.", "$1 Ausgaben sind übrig.");
regGS("Change publication information", "Information der Publikation ändern");
regGS("Time Unit", "Zeiteinheit");
regGS("Currency", "Währung");
regGS("Edit languages", "Sprachen bearbeiten");
?>
